<?php

/**
 * The file that defines the core plugin class
 *
 * A class definition that includes attributes and functions used across both the
 * public-facing side of the site and the admin area.
 *
 * @link       https://themeatelier.net
 * @since      1.0.0
 *
 * @package    Domina_Pro
 * @subpackage Domina_Pro/includes
 */

/**
 * The core plugin class.
 *
 * This is used to define internationalization, admin-specific hooks, and
 * public-facing site hooks.
 *
 * Also maintains the unique identifier of this plugin as well as the current
 * version of the plugin.
 *
 * @since      1.0.0
 * @package    Domina_Pro
 * @subpackage Domina_Pro/includes
 * @author     ThemeAtelier <themeatelierbd@gmail.com>
 */
class Domina_Pro
{

	/**
	 * The loader that's responsible for maintaining and registering all hooks that power
	 * the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      Domina_Pro_Loader    $loader    Maintains and registers all hooks for the plugin.
	 */
	protected $loader;

	/**
	 * The unique identifier of this plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $plugin_name    The string used to uniquely identify this plugin.
	 */
	protected $plugin_name;

	/**
	 * The current version of the plugin.
	 *
	 * @since    1.0.0
	 * @access   protected
	 * @var      string    $version    The current version of the plugin.
	 */
	protected $version;

	/**
	 * Define the core functionality of the plugin.
	 *
	 * Set the plugin name and the plugin version that can be used throughout the plugin.
	 * Load the dependencies, define the locale, and set the hooks for the admin area and
	 * the public-facing side of the site.
	 *
	 * @since    1.0.0
	 */
	public function __construct()
	{
		if (defined('DOMINA_PRO_VERSION')) {
			$this->version = DOMINA_PRO_VERSION;
		} else {
			$this->version = '1.0.0';
		}
		$this->plugin_name = 'domina-pro';

		$this->load_dependencies();
		$this->set_locale();
		$this->define_public_hooks();

		add_action('template_redirect', array($this, 'domina'));
		add_shortcode('dom_contact_form', array($this, 'dom_shortcode'));
	}

	/**
	 * Load the required dependencies for this plugin.
	 *
	 * Include the following files that make up the plugin:
	 *
	 * - Domina_Pro_Loader. Orchestrates the hooks of the plugin.
	 * - Domina_Pro_i18n. Defines internationalization functionality.
	 * - Domina_Pro_Admin. Defines all hooks for the admin area.
	 * - Domina_Pro_Public. Defines all hooks for the public side of the site.
	 *
	 * Create an instance of the loader which will be used to register the hooks
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function load_dependencies()
	{

		/**
		 * The class responsible for orchestrating the actions and filters of the
		 * core plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-domina-pro-loader.php';

		/**
		 * The class responsible for defining internationalization functionality
		 * of the plugin.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'includes/class-domina-pro-i18n.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'admin/classes/setup.class.php';
		require_once plugin_dir_path(dirname(__FILE__)) . 'admin/config/admin-options.php';

		/**
		 * The class responsible for defining all actions that occur in the public-facing
		 * side of the site.
		 */
		require_once plugin_dir_path(dirname(__FILE__)) . 'public/class-domina-pro-public.php';

		$this->loader = new Domina_Pro_Loader();
	}

	/**
	 * Define the locale for this plugin for internationalization.
	 *
	 * Uses the Domina_Pro_i18n class in order to set the domain and to register the hook
	 * with WordPress.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function set_locale()
	{

		$plugin_i18n = new Domina_Pro_i18n();

		$this->loader->add_action('plugins_loaded', $plugin_i18n, 'load_plugin_textdomain');
	}


	/**
	 * Register all of the hooks related to the public-facing functionality
	 * of the plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 */
	private function define_public_hooks()
	{

		$plugin_public = new Domina_Pro_Public($this->get_plugin_name(), $this->get_version());

		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_styles');
		$this->loader->add_action('wp_enqueue_scripts', $plugin_public, 'enqueue_scripts');
	}

	/**
	 * Run the loader to execute all of the hooks with WordPress.
	 *
	 * @since    1.0.0
	 */
	public function run()
	{
		$this->loader->run();
	}

	/**
	 * The name of the plugin used to uniquely identify it within the context of
	 * WordPress and to define internationalization functionality.
	 *
	 * @since     1.0.0
	 * @return    string    The name of the plugin.
	 */
	public function get_plugin_name()
	{
		return $this->plugin_name;
	}

	/**
	 * The reference to the class that orchestrates the hooks with the plugin.
	 *
	 * @since     1.0.0
	 * @return    Domina_Pro_Loader    Orchestrates the hooks of the plugin.
	 */
	public function get_loader()
	{
		return $this->loader;
	}

	/**
	 * Retrieve the version number of the plugin.
	 *
	 * @since     1.0.0
	 * @return    string    The version number of the plugin.
	 */
	public function get_version()
	{
		return $this->version;
	}

	public function domina()
	{
		$options = get_option('dom_opt');
		if ($options['dom_enable']) {
			if ($options['dom_template'] == 'template-1') {
				include(DOM_DIR_PATH . 'public/templates/template-1.php');
				die();
			} else {
				include(DOM_DIR_PATH . 'public/templates/template-2.php');
				die();
			}
		};
	}

	public function domina_html_form_code(){
		$options = get_option('dom_opt');
		echo '<form action="' . esc_url($_SERVER['REQUEST_URI']) . '" method="post" id="contact-form">
		
		<div class=" mb13">';
		if ($options['dom_namelabel']) :
			echo '<label  class="form-label" for="dom_name"><span>' . esc_html($options['dom_namelabel']) . '</span></label>';
		endif;
		echo '<input id="dom_name" class="contact-name" required placeholder="' . esc_html($options['dom_nameplaceholder']) . '" type="text" name="dom_name" pattern="[a-zA-Z0-9 ]+"/>
		
		</div>
		<div class="mb13">';
		if ($options['dom_emaillabel']) :
			echo '<label  class="form-label" for="dom_email"><span>' . esc_html($options['dom_emaillabel']) . '</span></label>';
		endif;
		echo '<input id="dom_email" class="contact-name" required placeholder="' . esc_html($options['dom_emailplaceholder']) . '" type="email" name="dom_email"/>
		</div>
		
		<div class="mb13">';
		if ($options['dom_subjectlabel']) :
			echo '<label  class="form-label" for="dom_subject"><span>' . esc_html($options['dom_subjectlabel']) . '</span></label>';
		endif;
		echo '<input id="dom_subject" class="contact-name" required placeholder="' . esc_html($options['dom_subjectplaceholder']) . '" type="text" name="dom_subject"/>
		</div>
		
		<div class="mb13">';
		if ($options['dom_proposallabel']) :
			echo '<label  class="form-label" for="dom_proposal"><span>' . esc_html($options['dom_proposallabel']) . '</span></label>';
		endif;
		echo '<textarea id="dom_proposal" name="dom_proposal" rows="4" class="contact-name field-message"
		placeholder="' . esc_html($options['dom_proposalplaceholder']) . '"
		required></textarea>
	
	</div>
		
		<input class="btn btn-default btn-filled" type="submit" name="dom_submitted" value="' . esc_html($options['dom_buttonlabel']) . '"></form>';
	}

	public function domina_deliver_mail() {
		$data = array(
			'type' => null,
			'title' => null,
			'description' => null,
			'okay' => null,
		);

		// if the submit button is clicked, send the email
		if (isset($_POST['dom_submitted'])) {
			// sanitize form values
			$name      = sanitize_text_field($_POST['dom_name']);
			$email     = sanitize_email($_POST['dom_email']);
			$subject   = sanitize_text_field($_POST['dom_subject']);
			$message   = sanitize_textarea_field($_POST['dom_proposal']);
			$date      = date('F j, Y, H:i (h:i A) (\G\M\T O)');
			$ip = esc_sql(sanitize_text_field($_SERVER['REMOTE_ADDR']));
			$siteURL = get_site_url();
			$options = get_option('dom_opt');

			$variables = array('{from}', '{subject}', '{email}', '{message}', '{siteURL}', '{date}', '{ip}');
			$values = array($name, $subject, $email, $message, $siteURL, $date, $ip);
			$text = trim(str_replace($variables, $values, $options['dom_emaitemplate']));
			$headers = array('From: ' . $name . ' <' . $email . '>');

			// If email has been process for sending, display a success message
			if (wp_mail($options['dom_targetemail'], $subject, $text, $headers)) {
				$data = array(
					'type' => 'success',
					'title' => $options['dom_success-title'],
					'description' => $options['dom_success-description'],
					'okay' => null,
				);
			} else {
				$data = array(
					'type' => 'error',
					'title' => $options['dom_error-title'],
					'description' => $options['dom_error-description'],
					'okay' => $options['dom_error-okay'],
				);
			}
		}
		wp_localize_script('domina-custom', 'confirmation', $data);
	}

	public function dom_shortcode()
	{
		ob_start();
		$this->domina_deliver_mail();
		$this->domina_html_form_code();
		return ob_get_clean();
	}
}
